module.exports = defineTest({
	description: 'preserves comments before imports'
});
